Index: chrome/browser/policy/cloud/user_cloud_policy_store_base.h |
diff --git a/chrome/browser/policy/cloud/user_cloud_policy_store_base.h b/chrome/browser/policy/cloud/user_cloud_policy_store_base.h |
index 514983a8d1098783db1174ef217938d6bb77da7b..6cedbc458e698440020303f1acbfcc3aba0db24a 100644 |
--- a/chrome/browser/policy/cloud/user_cloud_policy_store_base.h |
+++ b/chrome/browser/policy/cloud/user_cloud_policy_store_base.h |
@@ -27,10 +27,12 @@ class UserCloudPolicyStoreBase : public CloudPolicyStore { |
scoped_ptr<UserCloudPolicyValidator> CreateValidator( |
scoped_ptr<enterprise_management::PolicyFetchResponse> policy); |
// Sets |policy_data| and |payload| as the active policy. |
void InstallPolicy( |
scoped_ptr<enterprise_management::PolicyData> policy_data, |
- scoped_ptr<enterprise_management::CloudPolicySettings> payload); |
+ scoped_ptr<enterprise_management::CloudPolicySettings> payload, |
+ uint32 policy_hash_value); |
private: |
DISALLOW_COPY_AND_ASSIGN(UserCloudPolicyStoreBase); |
@@ -27,10 +27,12 @@ class UserCloudPolicyStoreBase : public CloudPolicyStore { |
scoped_ptr<UserCloudPolicyValidator> CreateValidator( |
scoped_ptr<enterprise_management::PolicyFetchResponse> policy); |
- // Sets |policy_data| and |payload| as the active policy. |
+ // Sets |policy_data| and |payload| with hash |policy_hash_value| as the |
+ // active policy. |
void InstallPolicy( |
scoped_ptr<enterprise_management::PolicyData> policy_data, |